CURRENT_SHELL=""
if [ -n "$BASH_VERSION" ]; then
  CURRENT_SHELL=bash
elif [ -n "$ZSH_VERSION" ]; then
  CURRENT_SHELL=zsh
fi
if [ "$CURRENT_SHELL" = "zsh" ]; then
  export CLASH_PURE=$(dirname $(readlink -f "$0"))
elif [ "$CURRENT_SHELL" = "bash" ]; then
  export CLASH_PURE=$(dirname "$(readlink -f ${BASH_SOURCE[0]})")
else
  echo "- Clash Pure not available on sh, plz use zsh/bash."
  return 1
fi
unset CURRENT_SHELL
function setproxy() {
    local port=${1:-7890}      # proxy port, default = 7890
    local host=${2:-127.0.0.1} # proxy host, default = 127.0.0.1
    export http_proxy=http://$host:$port && export https_proxy=$http_proxy
    echo "- You've set the proxy success! Info: $http_proxy"
}
function unsetproxy() {
    unset http_proxy && unset https_proxy && unset no_proxy
    echo "- You've unset the proxy success!"
}
function clash-pure() {
    if [[ "$1" == "start" ]]; then
        if pgrep -f clash-pure-core >/dev/null; then
            pkill -f clash-pure-core
            echo "-- restart clash-pure..."
        else
            echo "-- start clash-pure..."
        fi
        $CLASH_PURE/bin/clash-pure-core -d $CLASH_PURE/profile &
	disown
        sleep 1

    elif [[ "$1" == "stop" ]]; then
        if pgrep -f clash-pure-core >/dev/null; then
            pkill -f clash-pure-core
            echo "-- stop clash-pure"
        else
            echo "-- clash-pure not run"
        fi

    elif [[ "$1" == "select" ]]; then
        $CLASH_PURE/bin/clashcli -p 9090
    elif [[ "$1" == "status" ]]; then
        if pgrep -f clash-pure-core >/dev/null; then
            echo "Clash Pure is running."
        else
	    echo -e "Clash Pure is stopped. Try \e[36mclash-pure start\e[0m for usage."
	fi
    else
        cat <<EOF
Clash Pure, a terminal proxy client for the linux server. Version 1.1

  Usage:
    -- For start clash service
    clash-pure start        Run the clash service in the background;
    clash-pure stop         Stop the clash service;
    clash-pure select       Select the netwrok node of the clash profile;
    clash-pure status	    Show whether Clash Pure is running or not;

    -- For switch network proxy
    setproxy [port] [host]  Quick set proxy environments for current shell.
    unsetproxy		    Quick remove proxy environments when not needed.

  Tip:
    Clash Pure uses 'pure' as the alias of clash-pure.
    Try 'pure start, pure stop...'
EOF
    fi
    echo ""
}
alias pure=clash-pure
